@@ -59,5 +59,7 @@ extern int   dg_str2code(char *, char **, char *, char *);
 // ¸ʸ֤褦ȤС
 extern char *str2code_replace(char *, char *, char *);
 extern int   dg_str2code_replace(char *, char **, char *, char *);
+// ¸ʸ֤褦ȤС+Ѵ
+extern int   dg_str2code_replace_validate(char *, char **, char *, char *, char **, char *, size_t);
 
 #endif  /* _LIBDGSTR_H_ */
