@@ -17,7 +17,7 @@
 
 char *parse_command(char *string, char ***list);
 void free_arg_list(char **list);
-int exec_external(GMimeObject *part, char **cmd_arg, char **output, size_t *output_len, sender_check_arg_t *data, int timeout);
+int exec_external(GMimeObject *part, char **cmd_arg, char **output, size_t *output_len, sender_check_arg_t *data, int timeout, int next_msg);
 extern char *is_executable_file(char *);
 
 #endif		/* _EXEC_COMMAND_H */
