@@ -653,10 +653,22 @@ mlfi_eoh(SMFICTX *ctx)
     }
 
     if (ismode_harmless) {
+        priv->mlfi_safetysendercheck = NOTSAFETYSENDER_CHECK;
         ret = check_sender(priv);
         switch (ret) {
             case SENDER_CHECK_OK:
-                return SMFIS_ACCEPT;
+                if (priv->mlfi_conf->cf_safetysenderharmlessconf == NULL) {
+                    // SafetySenderHarmlessConfが設定されていなければそのまま
+                    return SMFIS_ACCEPT;
+                } else {
+                    // SafetySenderHarmlessConfが設定されていたらフラグ立てる
+                    priv->mlfi_safetysendercheck = SAFETYSENDER_CHECK;
+                    // 無害化処理へ
+                    break;
+                }
+            case SENDER_CHECK_NONE:
+            // SenderCheck=noneの場合は、何もせずに終了
+                 return SMFIS_ACCEPT;
             case SENDER_CHECK_NG:
                 log(
                     LOG_HARMLESS
