@@ -53,6 +53,8 @@
 #define CODE_INVALID_FILENAME	"550"
 #define XCODE_INVALID_FILENAME	"5.7.1"
 #define MESSAGE_INVALID_FILENAME "Your attachment filename may include invalid encoding. Please rename attachment file and resend."
+#define NOTSAFETYSENDER_CHECK		0
+#define SAFETYSENDER_CHECK		1
 
 /* milter */
 sfsistat mlfi_connect(SMFICTX *, char *, _SOCK_ADDR *);
@@ -86,6 +88,7 @@ struct mlfiPriv
     struct rcptaddr *mlfi_savebcc;
     int             mlfi_whitelist;
     sender_check_arg_t mlfi_sendercheck_arg;
+    int		    mlfi_safetysendercheck;
 #ifdef __CUSTOMIZE2018
     int             mlfi_subject_lang;
     int             mlfi_sencstatus;
